Index: invariantview/perspectives/invariant/invariant.py
===================================================================
--- invariantview/perspectives/invariant/invariant.py	(revision 4da35bce2f399383ece20220161d3f98edb34fe6)
+++ invariantview/perspectives/invariant/invariant.py	(revision 9b187350a27b63e0f6acf1eba38d6f445fbe7eae)
@@ -265,5 +265,5 @@
         """
         Call-back method for the state reader.
-        This method is called when a .inv file is loaded.
+        This method is called when a .inv/.svs file is loaded.
         
         :param state: State object
@@ -271,6 +271,8 @@
         self.temp_state = None
         try:
+            
             if datainfo is None:
                 raise RuntimeError, "invariant.set_state: datainfo parameter cannot be None in standalone mode"
+            
             datainfo.meta_data['invstate'].file = datainfo.meta_data['invstate'].file
             datainfo.name = datainfo.meta_data['invstate'].file
@@ -283,18 +285,23 @@
             # set state
             self.invariant_panel.is_state_data = True
-            # Load the invariant states
+            
             # Make sure the user sees the invariant panel after loading
             self.parent.set_perspective(self.perspective)
+            # Load the invariant states
             self.temp_state = temp_state
             #self.invariant_panel.set_state(state=temp_state,data=self.__data)         
-
+            
         except:
             logging.error("invariant.set_state: %s" % sys.exc_value)
             
-    def on_set_state_helper(self,event=None):
-        """
+    def on_set_state_helper(self, event=None):
+        """
+        Set the state when called by EVT_STATE_UPDATE event from guiframe
+        after a .inv/.svs file is loaded 
         """
         self.invariant_panel.set_state(state=self.temp_state,data=self.__data)
         self.temp_state = None
+        
+        
         
     def plot_theory(self, data=None, name=None):
Index: invariantview/perspectives/invariant/invariant_panel.py
===================================================================
--- invariantview/perspectives/invariant/invariant_panel.py	(revision 085bf4c71407b9a310b08030d303194f04e92d0c)
+++ invariantview/perspectives/invariant/invariant_panel.py	(revision 9b187350a27b63e0f6acf1eba38d6f445fbe7eae)
@@ -123,4 +123,5 @@
         if self._data is not None:
             self.err_check_on_data()
+            self.get_state_by_num(0)
             data_name = self._data.name
             data_qmin = min (self._data.x)
@@ -132,4 +133,7 @@
             self.compute_invariant(event=None)
             self.state.file = self._data.name
+            #Reset the list of states
+            self.state.data = copy.deepcopy(data)
+            self._reset_state_list()
         return True  
     def set_message(self):
@@ -159,5 +163,5 @@
     def set_state(self,state=None,data=None):
         """
         set state when loading it from a .inv file
         """
         if state == None or data == None:
@@ -197,5 +201,28 @@
             self.is_state_data = False
 
-            
+    def clear_panel(self, format='.svs'):
+        """
+        Clear panel to defaults, used by set_state of manager
+        """
+        if format == '.svs':
+            self._data = None
+            # default data testctrl
+            self.hint_msg_txt.SetLabel('')
+            data_name = ''
+            data_qmin = ''
+            data_qmax = ''
+            self.data_name_tcl.SetValue(str(data_name))
+            self.data_min_tcl.SetLabel(str(data_qmin))
+            self.data_max_tcl.SetLabel(str(data_qmax))
+            #reset output textctrl
+            self._reset_output()
+            #reset panel
+            self.reset_panel()
+            #reset state w/o data
+            self.set_state()
+            # default flags for state
+            self.new_state = False
+            self.is_state_data = False
+            self.is_power_out = False
 
     def get_background(self):
@@ -744,4 +771,5 @@
         self.button_bookmark.Disable()
         self.button_report.Disable()
+        self.button_save.Disable() 
         self.button_calculate.SetFocus()
         #self.SetupScrolling()
@@ -159,5 +163,5 @@
     def set_state(self,state=None,data=None):
         """
-        set state when loading it from a .inv file
+        set state when loading it from a .inv/.svs file
         """
         if state == None or data == None:
